
// $Id: AcpiConfigurationDialog.cpp,v 1.24 2014/02/10 10:41:08 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AcpiConfigurationDialog.h"
#include "AcpiConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "BaseIconNames.h"
#include "OptionBrowsedLineEditor.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionSpinBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace Acpi
{

    //_________________________________________________________
    AcpiConfigurationDialog::AcpiConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "AcpiConfigurationDialog::AcpiConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - Battery Monitor" ) );

        // generic widgets
        QWidget* page;
        QGroupBox *box;
        OptionColorDisplay *colorDisplay;
        OptionCheckBox* checkbox;
        OptionBrowsedLineEditor* editor;

        // misc
        page = &addPage( IconEngine::get( IconNames::PreferencesUnsorted ), tr( "Unsorted" ), tr( "Additional unsorted settings" ) );

        // colors
        page->layout()->addWidget( box = new QGroupBox( tr( "Colors" ), page ));

        QLabel* label;
        GridLayout* gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(5);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->setLayout( gridLayout );

        gridLayout->addWidget( label = new QLabel( tr( "Normal:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "NORMAL_COLOR" ) );
        addOptionWidget( colorDisplay );
        label->setBuddy( colorDisplay );

        gridLayout->addWidget( label = new QLabel( tr( "Low:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "LOW_COLOR" ) );
        addOptionWidget( colorDisplay );
        label->setBuddy( colorDisplay );

        gridLayout->addWidget( label = new QLabel( tr( "Critical:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "CRITICAL_COLOR" ) );
        addOptionWidget( colorDisplay );
        label->setBuddy( colorDisplay );

        // thresholds
        page->layout()->addWidget( box = new QGroupBox( tr( "Thresholds" ), page ));

        gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(5);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->setLayout( gridLayout );

        OptionSpinBox* spinbox;
        gridLayout->addWidget( label = new QLabel( tr( "Low level threshold:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "LOW_THRESHOLD" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );
        spinbox->setSuffix( "%" );
        spinbox->setMinimum(0);
        spinbox->setMaximum(100);

        gridLayout->addWidget( label = new QLabel( tr( "Critical level threshold:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "CRITICAL_THRESHOLD" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );
        spinbox->setSuffix( "%" );
        spinbox->setMinimum(0);
        spinbox->setMaximum(100);

        // misc
        page->layout()->addWidget( box = new QGroupBox( tr( "Miscelaneous" ), page ));

        box->setLayout( new QVBoxLayout() );
        box->layout()->setSpacing(5);
        box->layout()->setMargin(5);

        gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->layout()->addItem( gridLayout );

        gridLayout->addWidget( label = new QLabel( tr( "Acpi command:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ACPI" ) );
        addOptionWidget( editor );
        label->setBuddy( editor );

        gridLayout->addWidget( label = new QLabel( tr( "Refresh interval:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "REFRESH_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between two refresh" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );

        box->layout()->addWidget( checkbox = new OptionCheckBox( tr( "Show status" ), box, "SHOW_LABEL" ) );
        addOptionWidget( checkbox );

        read();

    }
}
