
// $Id: CalendarConfigurationDialog.cpp,v 1.27 2014/02/10 10:07:45 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CalendarConfigurationDialog.h"
#include "CalendarConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionLineEditor.h"
#include "OptionSlider.h"
#include "OptionSpinBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>


namespace Calendar
{
    //_________________________________________________________
    CalendarConfigurationDialog::CalendarConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "CalendarConfigurationDialog::CalendarConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - Transparent Calendar" ) );

        QWidget* page = &addPage( IconEngine::get( IconNames::PreferencesAppearance), tr( "Appearance" ), tr( "Window appearance and colors" ) );
        {
            QGroupBox *box;
            page->layout()->addWidget( box = new QGroupBox( tr( "Colors" ), page ));

            OptionColorDisplay *colorDisplay;

            QVBoxLayout* boxLayout( new QVBoxLayout() );
            boxLayout->setSpacing(5);
            boxLayout->setMargin(5);
            box->setLayout( boxLayout );

            GridLayout* gridLayout = new GridLayout();
            gridLayout->setSpacing(5);
            gridLayout->setMargin(0);
            gridLayout->setMaxCount( 2 );
            gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
            boxLayout->addLayout( gridLayout );

            QLabel* label;
            gridLayout->addWidget( label = new QLabel( tr( "Current day:" ), box ) );
            gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "CURRENT_DAY_COLOR" ) );
            addOptionWidget( colorDisplay );
            label->setBuddy( colorDisplay );

            gridLayout->addWidget( label = new QLabel( tr( "Marked day:" ), box ) );
            gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "MARKED_DAY_COLOR" ) );
            addOptionWidget( colorDisplay );
            label->setBuddy( colorDisplay );

            // intensity
            OptionSlider *slider;
            gridLayout->addWidget( label = new QLabel( tr( "Intensity:" ), this ) );
            gridLayout->addWidget( slider = new OptionSlider( this, "TRANSPARENCY_BACKGROUND_INTENSITY" ) );
            slider->setScale( 1.0/2.55 );
            slider->setRange( 0, 100 );
            addOptionWidget( slider );

            OptionCheckBox *checkbox;
            boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use gradient" ), box, "TRANSPARENCY_USE_GRADIENT" ) );
            addOptionWidget( checkbox );

            page->layout()->addWidget( box = new QGroupBox( tr( "Flags" ), page ));
            boxLayout = new QVBoxLayout();
            boxLayout->setSpacing(5);
            boxLayout->setMargin(5);
            box->setLayout( boxLayout );

            boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show week numbers" ), box, "SHOW_WEEK_NUMBERS" ) );
            addOptionWidget( checkbox );

            boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show days from previous/next month" ), box, "SHOW_INVALID_DAYS" ) );
            addOptionWidget( checkbox );

            boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show past events" ), box, "SHOW_PAST_TAGS" ) );
            addOptionWidget( checkbox );

        }

        // notifications
        page = &addPage( IconEngine::get( IconNames::PreferencesNotifications ), tr( "Notifications" ), tr( "Configure events notifications" ) );
        {
            QGroupBox *box;
            page->layout()->addWidget( box = new QGroupBox( tr( "Email Configuration" ), page ));

            GridLayout* gridLayout = new GridLayout();
            gridLayout->setSpacing(5);
            gridLayout->setMargin(5);
            gridLayout->setMaxCount( 2 );
            gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
            box->setLayout( gridLayout );

            QLabel* label;
            OptionLineEditor* editor;
            gridLayout->addWidget( label = new QLabel( tr( "Host:" ), box ) );
            gridLayout->addWidget( editor = new OptionLineEditor( box, "SMTP_HOST" ) );
            addOptionWidget( editor );
            label->setBuddy( editor );

            OptionSpinBox* spinBox;
            gridLayout->addWidget( label = new QLabel( tr( "Port:" ), box ) );
            gridLayout->addWidget( spinBox = new OptionSpinBox( box, "SMTP_PORT" ) );
            spinBox->setMinimum( 0 );
            spinBox->setMaximum( 10000 );
            addOptionWidget( spinBox );
            label->setBuddy( spinBox );

            gridLayout->addWidget( label = new QLabel( tr( "Default sender:" ), box ) );
            gridLayout->addWidget( editor = new OptionLineEditor( box, "SMTP_SENDER" ) );
            addOptionWidget( editor );
            label->setBuddy( editor );

            gridLayout->addWidget( label = new QLabel( tr( "Default recipient:" ), box ) );
            gridLayout->addWidget( editor = new OptionLineEditor( box, "SMTP_RECIPIENT" ) );
            addOptionWidget( editor );
            label->setBuddy( editor );

        }

        read();
    }

}
