#ifndef AlarmModel_h
#define AlarmModel_h

// $Id: AlarmModel.h,v 1.11 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file AlarmModel.h
\brief alarm model
\author Hugo Pereira
\version $Revision: 1.11 $
\date $Date: 2014/02/18 15:15:56 $
*/

#include "Alarm.h"
#include "Counter.h"
#include "ListModel.h"

namespace Clock
{

    //! model
    class AlarmModel: public ListModel<Alarm>, public Counter
    {

        Q_OBJECT

        public:

        //! column type enumeration
        enum ColumnType
        {
            Enabled,
            Time,
            Text,
            Days,
            nColumns
        };

        //! constructor
        AlarmModel( QObject* parent = 0 ):
            ListModel<Alarm>( parent ),
            Counter( "AlarmModel" )
        {}

        //!@name methods reimplemented from base class
        //@{

        //! flags
        virtual Qt::ItemFlags flags(const QModelIndex& ) const
        { return Qt::ItemIsEnabled |  Qt::ItemIsSelectable; }

        //! return data
        virtual QVariant data(const QModelIndex &index, int role) const;

        //! header data
        virtual QVariant headerData(int section, Qt::Orientation, int role = Qt::DisplayRole) const;

        //! number of columns for a given index
        virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
        { return nColumns; }

        //@}

        protected:

        //! sort
        virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder );

        private:

        //! column names
        static const QString columnNames_[nColumns];

        //! used to sort options
        class SortFTor
        {

            public:

            //! constructor
            SortFTor( const ColumnType& type, Qt::SortOrder order = Qt::AscendingOrder ):
                type_( type ),
                order_( order )
            {}

            //! prediction
            bool operator() ( Alarm first, Alarm second ) const;

            private:

            //! column
            ColumnType type_;

            //! order
            Qt::SortOrder order_;

        };

    };
};

#endif
