// $Id: CpuLoad.cpp,v 1.21 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CpuLoad.h"
#include "Debug.h"

#include <QFile>
#include <QStringList>

namespace Cpu
{

    //________________________________________________
    CpuLoad::CpuLoad( void ):
        Counter( "CpuLoad" ),
        filename_( "/proc/stat" ),
        sampleSize_( 0 ),
        dataSize_( 0 )
    { timer_.start(); }

    //________________________________________________
    void CpuLoad::update( void )
    {

        // open file
        QFile in( filename_ );
        if( !in.open( QIODevice::ReadOnly ) )
        {
            Debug::Throw( "CpuLoad::update - cannot open file.\n" );
            return;
        }


        QStringList lines( QString( in.readAll() ).split( "\n" ) );
        for( QStringList::iterator iter = lines.begin(); iter != lines.end(); ++iter )
        {
            if( iter->indexOf( "cpu" ) < 0 ) break;

            QString cpuName;
            Data data;
            QTextStream( &*iter ) >> cpuName >> data;
            data.setTime( timer_.elapsed()/1000 );

            // initialize Samples if new
            if( sampleMap_.find( cpuName ) == sampleMap_.end() ) {
                sampleMap_[ cpuName ].setSampleSize( sampleSize_ );
                sampleMap_[ cpuName ].setDataSize( dataSize_ );
            }

            // add current data to matching sample
            sampleMap_[ cpuName ].add( data );

        }

        return;

    }

    //________________________________________________
    CpuLoad::DataList CpuLoad::data( const QString& cpuName ) const
    {

        SampleMap::const_iterator iter( sampleMap_.find( cpuName ) );
        if( iter == sampleMap_.end() ) return DataList();
        else return iter.value().data();

    }

    //________________________________________________
    void CpuLoad::Samples::setSampleSize( int sampleSize )
    {
        Debug::Throw() << "CpuLoad::Samples::setSampleSize: " << sampleSize << endl;
        sampleSize_ = sampleSize;
        while( sampleList_.size() > sampleSize_ )
        { sampleList_.removeFirst(); }
    }

    //________________________________________________
    void CpuLoad::Samples::setDataSize( int dataSize )
    {
        Debug::Throw() << "CpuLoad::Samples::setDataSize: " << dataSize << endl;
        dataSize_ = dataSize;
        while( dataList_.size() > dataSize_ )
        { dataList_.removeFirst(); }
    }

    //________________________________________________
    void CpuLoad::Samples::add( const CpuLoad::Data& data )
    {

        // add data to samples
        sampleList_ << data;

        // check size
        if( sampleList_.size() > sampleSize_ )
        {

            Data data( sampleList_.back()- sampleList_.front() );
            if( data.valid() ) dataList_ << data;
            if( dataList_.size() > dataSize_ ) dataList_.removeFirst();
            sampleList_.removeFirst();

        }

        return;

    }
}
