#ifndef MainWindow_h
#define MainWindow_h

// $Id: MainWindow.h,v 1.42 2014/02/10 11:08:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "TransparentWindow.h"

#include <QTimerEvent>

// forward declaration
class ConfigurationDialog;
class ToolTipWidget;

//! transparent MainWindow widget
class MainWindow : public TransparentWindow
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    MainWindow( QWidget *parent = 0 );

    //!@name actions
    //@{

    //! raise all
    QAction& _raiseAllAction( void ) const
    { return *raiseAllAction_; }

    //! close all
    QAction& _closeAllAction( void ) const
    { return *closeAllAction_; }

    //@]

    Q_SIGNALS:

    //! geometry changed
    void geometryChanged( QRect );

    protected:

    //!@name event handlers
    //@{

    //! generic event handler
    virtual bool event(QEvent *event);

    //! timer event
    virtual void timerEvent( QTimerEvent* );

    //! mouse move event [overloaded]
    virtual void mousePressEvent( QMouseEvent* );

    //! double click event
    virtual void mouseDoubleClickEvent( QMouseEvent* );

    //@}

    //! context menu
    virtual void _installContextMenuActions( BaseContextMenu* );

    //! tooltip widget
    bool _hasToolTipWidget( void ) const
    { return (bool) toolTipWidget_; }

    //! tooltip widget
    ToolTipWidget& _toolTipWidget( void );

    //! update widget tooltip, if any
    virtual bool _updateToolTip( void )
    { return false; }

    //! update timer
    virtual QBasicTimer& _updateTimer( void )
    { return updateTimer_; }

    //! refresh
    virtual const int& _refresh( void ) const
    { return refresh_; }

    protected Q_SLOTS:

    //! update configuration
    virtual void _updateConfiguration( void );

    private:

    //! install actions
    void _installActions( void );

    //! tooltip widget
    ToolTipWidget* toolTipWidget_;

    //! timer to redraw
    QBasicTimer updateTimer_;

    //! update delay (second)
    int refresh_;

    //!@name actions
    //@{

    //! raise all action
    QAction* raiseAllAction_;

    //! close all action
    QAction* closeAllAction_;

    //@}


};


#endif
