#ifndef NetworkWidget_h
#define NetworkWidget_h

// $Id: NetworkWidget.h,v 1.28 2014/02/10 11:08:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "HistogramWidget.h"
#include "NetworkMonitor.h"

#include <QAction>
#include <QActionGroup>
#include <QBasicTimer>
#include <QMap>
#include <QPainter>
#include <QTimerEvent>

//! network widgets
namespace Network {

    //! transparent network load widget
    class NetworkWidget : public HistogramWidget
    {

        //! Qt meta object functions
        Q_OBJECT

        public:

        //! constructor
        NetworkWidget( QWidget *parent=0 );

        //! destructor
        virtual ~NetworkWidget( void )
        {}

        //! tooltip
        virtual bool _updateToolTip( void );

        protected:

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //!@name event handlers
        //@{

        //! timer
        void timerEvent( QTimerEvent* );

        //! paint event [overloaded]
        void _paint( QPaintDevice&, const QRect& );

        //! resize event [overloaded]
        void resizeEvent( QResizeEvent* );

        //@}

        protected Q_SLOTS:

        //! opend configuration dialog
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        //! toggle display
        void _toggleDisplay( QAction* );

        private:

        //! install actions
        void _installActions( void );

        //! update display actions from mask
        void _updateDisplayActions( void );

        //! scale factor
        double _getScale( const NetworkLoad::DataList& ) const;

        //! draw load text
        void _paintLoad( QPainter&, QRect& );

        //! network object
        NetworkMonitor networkMonitor_;


        //!@name actions
        //@{

        //! display actions
        QActionGroup* displayActionGroup_;

        //! display actions
        typedef QMap<QAction*, NetworkLoad::DataType> DisplayActionMap;

        //! display actions
        DisplayActionMap displayActions_;

        //@}

        //!@name properties
        //@{

        //! display mask
        NetworkLoad::DataTypes displayMask_;

        //! color map
        typedef QMap< NetworkLoad::DataType, Color > ColorMap;

        //! color map
        ColorMap colorMap_;

        //@}

    };
}

#endif
