#ifndef PictureAttributesModel_h
#define PictureAttributesModel_h

// $Id: PictureAttributesModel.h,v 1.12 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureAttributes.h"
#include "Counter.h"
#include "ListModel.h"

#include <QIcon>
#include <QString>

namespace Pictures
{

    //! model
    class PictureAttributesModel: public ListModel<PictureAttributes>, public Counter
    {

        Q_OBJECT

        public:

        //! column type enumeration
        enum ColumnType
        {
            Icon,
            Filename,
            Visibility,
            nColumns
        };

        //! constructor
        PictureAttributesModel( QObject* parent = 0 ):
            ListModel<PictureAttributes>( parent ),
            Counter( "PictureAttributesModel" )
        {}

        //!@name methods reimplemented from base class
        //@{

        //! flags
        virtual Qt::ItemFlags flags( const QModelIndex& ) const
        { return Qt::ItemIsEnabled |  Qt::ItemIsSelectable; }

        //! return data
        virtual QVariant data( const QModelIndex&, int ) const;

        //! header data
        virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

        //! number of columns for a given index
        virtual int columnCount( const QModelIndex& = QModelIndex() ) const
        { return nColumns; }

        //@}

        //! clear icon cache
        static void clearIconCache( void )
        { _icons().clear(); }

        protected:

        //! sort
        virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
        {}

        private:

        //! icon
        static QIcon _icon( const QString& );

        //! icon cache
        typedef QHash<QString, QIcon> IconCache;

        //! type icon cache
        static IconCache& _icons();

        //! column names
        static const QString columnNames_[nColumns];

    };

};
#endif
